@@ -1,5 +1,5 @@
 from typing import Optional, List
-from datetime import datetime
+from datetime import datetime, date, time
 from uuid import UUID
 from sqlmodel import select
 from sqlalchemy.orm import selectinload,joinedload
@@ -120,7 +120,67 @@ class MedicalVisitRepository:
             
             medical_visits = session.exec(statement).all()
             return medical_visits
+
+    def get_by_daterange_command(self, start_date: datetime, end_date: datetime, active_only: bool = True, load_relations: bool = False) -> List[MedicalVisit]:
+        with get_session(self.tenant) as session:
+            statement = select(MedicalVisit).where(
+                    MedicalVisit.visit_date >= start_date
+                )
+            
+            if end_date is not None:
+                statement = statement.where(MedicalVisit.visit_date <= end_date)
+            if active_only:
+                statement = statement.where(MedicalVisit.is_active == True)
+            if load_relations:
+                statement = statement.options(
+                    joinedload(MedicalVisit.client),
+                    joinedload(MedicalVisit.collaborator),
+                    joinedload(MedicalVisit.speciality),
+                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_recipe_visits),
+                    selectinload(MedicalVisit.organ_system_reviews),
+                    selectinload(MedicalVisit.physical_exams)
+                )
+            
+            medical_visits = session.exec(statement).all()
+            return medical_visits
         
+    def get_by_targetdate_command(self, target_date: datetime, active_only: bool = True, load_relations: bool = False) -> List[MedicalVisit]:
+        with get_session(self.tenant) as session:
+
+            if isinstance(target_date, str):
+                try:
+                    target_date = datetime.strptime(target_date, "%Y-%m-%d")
+                except ValueError:
+                    raise ValueError("Invalid date format")
+
+            elif isinstance(target_date, date) and not isinstance(target_date, datetime):
+                target_date = datetime.combine(target_date, time.min)
+
+            start_of_day = datetime.combine(target_date.date(), datetime.min.time())
+            end_of_day = datetime.combine(target_date.date(), datetime.max.time())
+
+            statement = select(MedicalVisit).where(
+                    MedicalVisit.visit_date >= start_of_day,
+                    MedicalVisit.visit_date <= end_of_day
+                )
+
+            if active_only:
+                statement = statement.where(MedicalVisit.is_active == True)
+            if load_relations:
+                statement = statement.options(
+                    joinedload(MedicalVisit.client),
+                    joinedload(MedicalVisit.collaborator),
+                    joinedload(MedicalVisit.speciality),
+                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_recipe_visits),
+                    selectinload(MedicalVisit.organ_system_reviews),
+                    selectinload(MedicalVisit.physical_exams)
+                )
+            
+            medical_visits = session.exec(statement).all()
+            return medical_visits
+
     def get_by_collaboratorid_and_daterange_command(self, collaborator_id: UUID, start_date: datetime, end_date: datetime, active_only: bool = True, load_relations: bool = False) -> List[MedicalVisit]:
         with get_session(self.tenant) as session:
             statement = select(MedicalVisit).where(
@@ -149,6 +209,15 @@ class MedicalVisitRepository:
     def get_by_collaboratorid_and_targetdate_command(self, collaborator_id: UUID, target_date: datetime, active_only: bool = True, load_relations: bool = False) -> List[MedicalVisit]:
         with get_session(self.tenant) as session:
 
+            if isinstance(target_date, str):
+                try:
+                    target_date = datetime.strptime(target_date, "%Y-%m-%d")
+                except ValueError:
+                    raise ValueError("Invalid date format")
+
+            elif isinstance(target_date, date) and not isinstance(target_date, datetime):
+                target_date = datetime.combine(target_date, time.min)
+
             start_of_day = datetime.combine(target_date.date(), datetime.min.time())
             end_of_day = datetime.combine(target_date.date(), datetime.max.time())
 
